aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/pet_control/pet_element.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/titanic/pet_control/pet_element.h')
-rw-r--r--engines/titanic/pet_control/pet_element.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/titanic/pet_control/pet_element.h b/engines/titanic/pet_control/pet_element.h
index d4ca580349..a8f5000155 100644
--- a/engines/titanic/pet_control/pet_element.h
+++ b/engines/titanic/pet_control/pet_element.h
@@ -50,10 +50,10 @@ public:
CPetControl *petControl) {}
/**
* Sets up the element
*/
- virtual void setup(int val, const CString &name, CPetControl *petControl) {}
-
+ virtual void reset(const CString &name, CPetControl *petControl, PetElementMode mode) {}
+
/**
* Draw the item
*/
@@ -50,10 +50,10 @@ public:
CPetControl *petControl) {}
/**
- * Sets up the element
+ * Reset the element
*/